@@ -23,16 +23,15 @@ from aliyunsdkcloudauth.endpoint import endpoint_data
 class DescribeUploadInfoRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'DescribeUploadInfo')
-		self.set_method('POST')
+		RpcRequest.__init__(self, 'Cloudauth', '2019-03-07', 'DescribeUploadInfo','cloudauth')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
-	def get_Biz(self):
-		return self.get_query_params().get('Biz')
+	def get_SourceIp(self):
+		return self.get_query_params().get('SourceIp')
 
-	def set_Biz(self,Biz):
-		self.add_query_param('Biz',Biz)
\ No newline at end of file
+	def set_SourceIp(self,SourceIp):
+		self.add_query_param('SourceIp',SourceIp)
\ No newline at end of file
